@@ -207,11 +207,21 @@ class MI(Base):
             raise Exception(f'Invalid value : {index}({self.COL_TITLE})')
 
     def get_all_item(self, index: str = '') -> list:
+        """
+        Examples:
+            [('2020.05.12', '684.21'),\n
+            ('2020.05.13', '691.53'),...]
+        """
         if index == '':
             pass
         else:
             self.chg_index(index=index)
-        return super().get_all_doc()
+
+        rlist = []
+        for d in super().get_all_doc():
+            rlist.append((d['date'], d['value']))
+
+        return rlist
 
     # ========================특정 페이지 관련 함수들=======================
 
@@ -411,6 +421,7 @@ class C101(Corps):
         """
 
         해당 날짜의 데이터를 반환한다.
+        만약 리턴값이 없으면 None 을 반환한다.
 
         Args:
             date (str): 예 - 20201011(6자리숫자)
